@@ -7,8 +7,6 @@
 # (It may become useful if the test is moved to ./t subdirectory.)
 
 BEGIN { $| = 1; print "1..1\n"; }
-# This space is left blank intentionally
-END {print "not ok 1\n" unless $loaded;}
+# This space is left blank intentionallyEND {print "not ok 1\n" unless $loaded;}
 use Filter::CBC 'Rijndael','Filter::CBC test';
-RandomIVxO)Qr<;`C"ҡg
-SVH%7e@V
\ No newline at end of file
+RandomIVX"`!r1-Q@\rTW+Uj{qtkZ
\ No newline at end of file
